@@ -9,7 +9,8 @@ from sentry_sdk import capture_exception
 
 from rrtv_httprunner import loader, utils, exceptions
 from rrtv_httprunner.models import VariablesMapping, FunctionsMapping
-from rrtv_httprunner.utils import execute_sql, execute_cmd, get_statement_type, execute_redis, execute_mongo
+from rrtv_httprunner.utils import execute_sql, execute_cmd, get_statement_type, execute_redis, execute_mongo, \
+    remove_bracket_first
 
 absolute_http_url_regexp = re.compile(r"^https?://", re.I)
 
@@ -18,9 +19,11 @@ dolloar_regex_compile = re.compile(r"\$\$")
 # variable notation, e.g. ${var} or $var
 variable_regex_compile = re.compile(r"\$\{(\w+)\}|\$(\w+)")
 # function notation, e.g. ${func1($var_1, $var_3)}
-function_regex_compile = re.compile(r"\$\{(\w+)\(([\$\w\;\:\*\.\-/\s=,]*)\)\}")
-suffix_regex_compile1 = re.compile(r"\[\'(.*?)\'\]")
-suffix_regex_compile2 = "\[(.*?)\]"
+# function_regex_compile = re.compile(r"\$\{(\w+)\(([\$\w\;\!\:\*\.\-/\s=,]*)\)\}")
+function_regex_compile = re.compile(r"\$\{(\w+)\(((?!\$\{).*)\)\}")
+
+suffix_regex_compile1 = r'\[\'(.*?)\'\]'
+suffix_regex_compile2 = r"\[(.*?)\]"
 suffix = []
 suffix2 = []
 
@@ -373,19 +376,21 @@ def parse_string(
             var_value = get_mapping_variable(var_name, variables_mapping)
             global suffix
             global suffix2
-            suffix_re = re.findall(r'\[\'(.*?)\'\]', raw_string)
-            if suffix_re == []:
-                suffix_re = re.findall(r"\[(.*?)\]", str(raw_string))
+            suffix_re = re.findall(var_name + suffix_regex_compile1, raw_string)
+            if not suffix_re:
+                suffix_re = re.findall(var_name + suffix_regex_compile2, str(raw_string))
             if suffix_re:
                 if suffix_re[-1] == "]":
                     suffix2 = suffix_re[0]
                 else:
                     suffix = suffix_re[0]
-                var_value = var_value[suffix]
-                left_string = raw_string.split("[")[0]
-                right_string = raw_string.split("]")[1]
-                full_string = left_string + right_string
+                if isinstance(var_value, Text) or isinstance(var_value, int):
+                    var_value = var_value
+                else:
+                    var_value = var_value[suffix]
+                full_string = remove_bracket_first(raw_string)
                 raw_string = full_string
+
             if f"${var_name}" == raw_string or "${" + var_name + "}" == raw_string:
                 # raw_string is a variable, $var or ${var}, return its value directly
                 return var_value
@@ -430,7 +435,10 @@ def parse_data(
 
         if get_statement_type(var_value) == "sql":
             try:
-                value = execute_sql(variables_mapping["mysql"], var_value)
+                if "&&db:" in var_value:
+                    value = execute_sql(var_value.split("&&db:")[1], var_value.split("&&db:")[0])
+                else:
+                    value = execute_sql(variables_mapping["mysql"], var_value)
             except KeyError:  # 没配置数据源
                 raise exceptions.DBError("mysql datasource not configured")
             if value is None:  # 如果为None说明非select方法
@@ -457,12 +465,12 @@ def parse_data(
         else:
 
             if isinstance(var_value, dict):
-                if suffix2 != []:
+                if suffix2:
                     match_start_position = raw_data.index("]", 0)
                     parsed_string = raw_data[match_start_position + 1:]
                     if parsed_string != "" or parsed_string is not None:
                         p = parse_string(parsed_string, variables_mapping, functions_mapping)
-                        if suffix2 != []:
+                        if suffix2:
                             val = var_value[suffix2]
                             return parse_string_value(str(val) + str(p))
                         else:
